<a href="{{ sidebar_item.url | url }}" {% if sidebar_item.active %}data-active {% endif %}
    class="text-sm flex h-8 w-full items-center rounded-lg px-2 text-foreground underline-offset-2 font-normal hover:bg-accent hover:text-accent-foreground data-active:bg-accent data-active:font-medium data-active:text-accent-foreground">
    {{ sidebar_item.title }}
    {% if sidebar_item.meta.new %}
    {% include "components/new.html" %}
    {% endif %}
</a>